==> flutter_chat_ui-1.5.6.tar.gz: README.md <==
<br>

<p align="center">
  <a href="https://flyer.chat">
    <img src="https://flyer.chat/assets/logo-dark.svg" width="288px" alt="Flyer Chat Logo" />
  </a>
</p>

<h1 align="center">Flutter Chat UI</h1>

<p align="center">
  Actively maintained, community-driven chat UI implementation with an optional <a href="https://pub.dev/packages/flutter_firebase_chat_core">Firebase BaaS</a>.
</p>

<br>

<p align="center">
  <a href="https://pub.dartlang.org/packages/flutter_chat_ui">
    <img alt="Pub" src="https://img.shields.io/pub/v/flutter_chat_ui" />
  </a>
  <a href="https://github.com/flyerhq/flutter_chat_ui/actions?query=workflow%3Abuild">
    <img alt="Build Status" src="https://github.com/flyerhq/flutter_chat_ui/workflows/build/badge.svg" />
  </a>
  <a href="https://www.codefactor.io/repository/github/flyerhq/flutter_chat_ui">
    <img alt="CodeFactor" src="https://www.codefactor.io/repository/github/flyerhq/flutter_chat_ui/badge" />
  </a>
</p>

<br>

<p align="center">
  <a href="https://flyer.chat">
    <img alt="Chat Image" src="https://user-images.githubusercontent.com/14123304/121787953-a6121500-cbc9-11eb-83ff-db0435d2cd57.png" />
  </a>
</p>

<br>

Flyer Chat is a platform for creating in-app chat experiences using Flutter or [React Native](https://github.com/flyerhq/react-native-chat-ui). This repository contains chat UI implementation for Flutter.

* **Free, open-source and community-driven**. We offer no paid plugins and strive to create an easy-to-use, almost drop-in chat experience for any application. Contributions are more than welcome! Please read our [Contributing Guide](CONTRIBUTING.md).

* **Backend agnostic**. You can choose the backend you prefer. But if you don't have one, we provide our own free and open-source [Firebase implementation](https://pub.dev/packages/flutter_firebase_chat_core), which can be used to create a working chat in minutes. We are also working on our more advanced SaaS and self-hosted solutions.

* **Customizable**. Supports custom themes, locales and more. Check our [documentation](https://docs.flyer.chat/flutter/chat-ui/) for the info. More options are on the way, let us know if something is missing.

* **Minimum dependencies**. Our packages are lightweight. Use your favourite packages for selecting images, opening files etc. See the [example](https://github.com/flyerhq/flutter_chat_ui/blob/main/example/lib/main.dart) for possible implementation.

## Getting Started

### Requirements

`Dart >=2.16.0` and `Flutter >=2.0.0`

Read our [documentation](https://docs.flyer.chat/flutter/chat-ui/) or see the [example](https://github.com/flyerhq/flutter_chat_ui/tree/main/example) project.

## Contributing

Please read our [Contributing Guide](CONTRIBUTING.md) before submitting a pull request to the project.

## Code of Conduct

Flyer Chat has adopted the [Contributor Covenant](https://www.contributor-covenant.org) as its Code of Conduct, and we expect project participants to adhere to it. Please read [the full text](CODE_OF_CONDUCT.md) so that you can understand what actions will and will not be tolerated.

## License

Licensed under the [Apache License, Version 2.0](LICENSE)

==> flutter_chat_ui-1.6.3.tar.gz: README.md <==
<br>

<p align="center">
  <a href="https://flyer.chat">
    <img src="https://flyer.chat/assets/logo-dark.svg" width="288px" alt="Flyer Chat Logo" />
  </a>
</p>

<h1 align="center">Flutter Chat UI</h1>

<p align="center">
  Actively maintained, community-driven chat UI implementation with an optional <a href="https://pub.dev/packages/flutter_firebase_chat_core">Firebase BaaS</a>.
</p>

<br>

<p align="center">
  🇺🇦🇺🇦 We are Ukrainians. If you enjoy our work, please <a href="https://u24.gov.ua">consider donating</a> to help save our country. 🇺🇦🇺🇦
</p>

<br>

<p align="center">
  <a href="https://pub.dartlang.org/packages/flutter_chat_ui">
    <img alt="Pub" src="https://img.shields.io/pub/v/flutter_chat_ui" />
  </a>
  <a href="https://github.com/flyerhq/flutter_chat_ui/actions?query=workflow%3Abuild">
    <img alt="Build Status" src="https://github.com/flyerhq/flutter_chat_ui/workflows/build/badge.svg" />
  </a>
  <a href="https://www.codefactor.io/repository/github/flyerhq/flutter_chat_ui">
    <img alt="CodeFactor" src="https://www.codefactor.io/repository/github/flyerhq/flutter_chat_ui/badge" />
  </a>
</p>

<br>

<p align="center">
  <a href="https://flyer.chat">
    <img alt="Chat Image" src="https://user-images.githubusercontent.com/14123304/174447563-c7f9d268-711a-4cd8-a582-7645d359b0c8.jpg" />
  </a>
</p>

<br>

Flyer Chat is a platform for creating in-app chat experiences using Flutter or [React Native](https://github.com/flyerhq/react-native-chat-ui). This repository contains chat UI implementation for Flutter.

* **Free, open-source and community-driven**. We offer no paid plugins and strive to create an easy-to-use, almost drop-in chat experience for any application. Contributions are more than welcome! Please read our [Contributing Guide](CONTRIBUTING.md).

* **Backend agnostic**. You can choose the backend you prefer. But if you don't have one, we provide our own free and open-source [Firebase implementation](https://pub.dev/packages/flutter_firebase_chat_core), which can be used to create a working chat in minutes. We are also working on our more advanced SaaS and self-hosted solutions.

* **Customizable**. Supports custom themes, locales and more. Check our [documentation](https://docs.flyer.chat/flutter/chat-ui/) for the info. More options are on the way, let us know if something is missing.

* **Minimum dependencies**. Our packages are lightweight. Use your favourite packages for selecting images, opening files etc. See the [example](https://github.com/flyerhq/flutter_chat_ui/blob/main/example/lib/main.dart) for possible implementation.

## Getting Started

### Requirements

`Dart >=2.17.0` and `Flutter >=2.0.0`

Read our [documentation](https://docs.flyer.chat/flutter/chat-ui/) or see the [example](https://github.com/flyerhq/flutter_chat_ui/tree/main/example) project.

## Contributing

Please read our [Contributing Guide](CONTRIBUTING.md) before submitting a pull request to the project.

## Code of Conduct

Flyer Chat has adopted the [Contributor Covenant](https://www.contributor-covenant.org) as its Code of Conduct, and we expect project participants to adhere to it. Please read [the full text](CODE_OF_CONDUCT.md) so that you can understand what actions will and will not be tolerated.

## License

Licensed under the [Apache License, Version 2.0](LICENSE)
